@@ -16,8 +16,8 @@ Github: superolmo
 
 """
 
-__version__ = '0.5.0'
-__author__ = 'Claudio Olmi'
+__version__ = "0.5.0"
+__author__ = "Claudio Olmi"
 
 import json
 import re  # used for URL validation
@@ -30,10 +30,10 @@ from typing import List, Tuple
 import requests
 
 
-class Channel():
+class Channel:
     # Required by Hypnotix
     id = ""
-    name = "" # What is the difference between the below name and title?
+    name = ""  # What is the difference between the below name and title?
     logo = ""
     logo_path = ""
     group_title = ""
@@ -52,32 +52,32 @@ class Channel():
     raw = ""
 
     def __init__(self, xtream: object, group_title, stream_info):
-        stream_type = stream_info['stream_type']
+        stream_type = stream_info["stream_type"]
         # Adjust the odd "created_live" type
         if stream_type == "created_live" or stream_type == "radio_streams":
             stream_type = "live"
 
         if stream_type != "live" and stream_type != "movie":
             print("Error the channel has unknown stream type `{}`\n`{}`".format(
-                stream_type,stream_info
+                stream_type, stream_info
             ))
         else:
             # Raw JSON Channel
             self.raw = stream_info
 
-            stream_name = stream_info['name']
+            stream_name = stream_info["name"]
 
             # Required by Hypnotix
-            self.id = stream_info['stream_id']
+            self.id = stream_info["stream_id"]
             self.name = stream_name
-            self.logo = stream_info['stream_icon']
+            self.logo = stream_info["stream_icon"]
             self.logo_path = xtream._get_logo_local_path(self.logo)
             self.group_title = group_title
             self.title = stream_name
 
             # Check if category_id key is available
             if "category_id" in stream_info.keys():
-                self.group_id = int(stream_info['category_id'])
+                self.group_id = int(stream_info["category_id"])
 
             if stream_type == "live":
                 stream_extension = "ts"
@@ -86,26 +86,26 @@ class Channel():
                 self.is_adult = 0
                 # Check if is_adult key is available
                 if "is_adult" in stream_info.keys():
-                    self.is_adult = int(stream_info['is_adult'])
+                    self.is_adult = int(stream_info["is_adult"])
 
                 # Check if epg_channel_id key is available
                 if "epg_channel_id" in stream_info.keys():
-                    self.epg_channel_id = stream_info['epg_channel_id']
+                    self.epg_channel_id = stream_info["epg_channel_id"]
 
-                self.added = stream_info['added']
+                self.added = stream_info["added"]
 
             elif stream_type == "movie":
-                stream_extension = stream_info['container_extension']
+                stream_extension = stream_info["container_extension"]
 
             # Required by Hypnotix
             self.url = "{}/{}/{}/{}/{}.{}".format(
                 xtream.server,
-                stream_info['stream_type'],
-                xtream.authorization['username'],
-                xtream.authorization['password'],
-                stream_info['stream_id'],
-                stream_extension
-                )
+                stream_info["stream_type"],
+                xtream.authorization["username"],
+                xtream.authorization["password"],
+                stream_info["stream_id"],
+                stream_extension,
+            )
 
             # Check that the constructed URL is valid
             if not xtream._validate_url(self.url):
@@ -114,13 +114,14 @@ class Channel():
     def export_json(self):
         jsondata = {}
 
-        jsondata['url'] = self.url
+        jsondata["url"] = self.url
         jsondata.update(self.raw)
-        jsondata['logo_path'] = self.logo_path
+        jsondata["logo_path"] = self.logo_path
 
         return jsondata
 
-class Group():
+
+class Group:
     # Required by Hypnotix
     name = ""
     group_type = ""
@@ -151,13 +152,14 @@ class Group():
                 stream_type, group_info
             ))
 
-        self.name = group_info['category_name']
+        self.name = group_info["category_name"]
 
         # Check if category_id key is available
         if "category_id" in group_info.keys():
-            self.group_id = int(group_info['category_id'])
+            self.group_id = int(group_info["category_id"])
 
-class Episode():
+
+class Episode:
     # Required by Hypnotix
     title = ""
     name = ""
@@ -171,31 +173,31 @@ class Episode():
         # Raw JSON Episode
         self.raw = episode_info
 
-        self.title = episode_info['title']
+        self.title = episode_info["title"]
         self.name = self.title
         self.group_title = group_title
-        self.id = episode_info['id']
-        self.container_extension = episode_info['container_extension']
-        self.episode_number = episode_info['episode_num']
-        self.av_info = episode_info['info']
+        self.id = episode_info["id"]
+        self.container_extension = episode_info["container_extension"]
+        self.episode_number = episode_info["episode_num"]
+        self.av_info = episode_info["info"]
 
-        self.logo = series_info['cover']
+        self.logo = series_info["cover"]
         self.logo_path = xtream._get_logo_local_path(self.logo)
 
-
         self.url = "{}/series/{}/{}/{}.{}".format(
             xtream.server,
-            xtream.authorization['username'],
-            xtream.authorization['password'],
+            xtream.authorization["username"],
+            xtream.authorization["password"],
             self.id,
-            self.container_extension
-            )
+            self.container_extension,
+        )
 
         # Check that the constructed URL is valid
         if not xtream._validate_url(self.url):
             print("{} - Bad URL? `{}`".format(self.name, self.url))
 
-class Serie():
+
+class Serie:
     # Required by Hypnotix
     name = ""
     logo = ""
@@ -215,8 +217,8 @@ class Serie():
         self.raw = series_info
 
         # Required by Hypnotix
-        self.name = series_info['name']
-        self.logo = series_info['cover']
+        self.name = series_info["name"]
+        self.logo = series_info["cover"]
         self.logo_path = xtream._get_logo_local_path(self.logo)
 
         self.seasons = {}
@@ -224,21 +226,22 @@ class Serie():
 
         # Check if category_id key is available
         if "series_id" in series_info.keys():
-            self.series_id = int(series_info['series_id'])
+            self.series_id = int(series_info["series_id"])
 
         # Check if plot key is available
         if "plot" in series_info.keys():
-            self.plot = series_info['plot']
+            self.plot = series_info["plot"]
 
         # Check if youtube_trailer key is available
         if "youtube_trailer" in series_info.keys():
-            self.youtube_trailer = series_info['youtube_trailer']
+            self.youtube_trailer = series_info["youtube_trailer"]
 
         # Check if genre key is available
         if "genre" in series_info.keys():
-            self.genre = series_info['genre']
+            self.genre = series_info["genre"]
 
-class Season():
+
+class Season:
     # Required by Hypnotix
     name = ""
 
@@ -246,7 +249,8 @@ class Season():
         self.name = name
         self.episodes = {}
 
-class XTream():
+
+class XTream:
 
     name = ""
     server = ""
@@ -265,7 +269,7 @@ class XTream():
     series = []
     movies = []
 
-    state = {'authenticated': False, 'loaded': False}
+    state = {"authenticated": False, "loaded": False}
 
     hide_adult_content = False
 
@@ -279,16 +283,17 @@ class XTream():
     )
     # If the cached JSON file is older than threshold_time_sec then load a new
     # JSON dictionary from the provider
-    threshold_time_sec = 60*60*8
+    threshold_time_sec = 60 * 60 * 8
 
-    def __init__(self,
-                provider_name: str,
-                provider_username: str,
-                provider_password: str,
-                provider_url: str,
-                hide_adult_content: bool = False,
-                cache_path: str = ""
-                ):
+    def __init__(
+        self,
+        provider_name: str,
+        provider_username: str,
+        provider_password: str,
+        provider_url: str,
+        hide_adult_content: bool = False,
+        cache_path: str = "",
+    ):
         """Initialize Xtream Class
 
         Args:
@@ -342,7 +347,7 @@ class XTream():
         search_result = []
 
         if ignore_case:
-            regex = re.compile(keyword,re.IGNORECASE)
+            regex = re.compile(keyword, re.IGNORECASE)
         else:
             regex = re.compile(keyword)
 
@@ -362,13 +367,12 @@ class XTream():
                 search_result.append(stream.export_json())
 
         if return_type == "JSON":
-            if search_result != None:
-                print("Found {} results `{}`".format(len(search_result),keyword))
+            if search_result is not None:
+                print("Found {} results `{}`".format(len(search_result), keyword))
                 return json.dumps(search_result, ensure_ascii=False)
         else:
             return search_result
 
-
     def _slugify(self, string: str) -> str:
         """Normalize string
 
@@ -385,12 +389,14 @@ class XTream():
 
     def _validate_url(self, url: str) -> bool:
         regex = re.compile(
-            r'^(?:http|ftp)s?://' # http:// or https://
-            r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
-            r'localhost|' #localhost...
-            r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' # ...or ip
-            r'(?::\d+)?' # optional port
-            r'(?:/?|[/?]\S+)$', re.IGNORECASE)
+            r"^(?:http|ftp)s?://"  # http:// or https://
+            r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"  # domain...
+            r"localhost|"  # localhost...
+            r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})"  # ...or ip
+            r"(?::\d+)?"  # optional port
+            r"(?:/?|[/?]\S+)$",
+            re.IGNORECASE,
+        )
 
         return re.match(regex, url) is not None
 
@@ -404,22 +410,21 @@ class XTream():
             [type]: The logo path as a string or None
         """
         local_logo_path = None
-        if logo_url != None:
+        if logo_url is not None:
             if not self._validate_url(logo_url):
                 logo_url = None
             else:
                 local_logo_path = osp.join(self.cache_path, "{}-{}".format(
                     self._slugify(self.name),
                     self._slugify(osp.split(logo_url)[-1])
-                    )
+                )
                 )
         return local_logo_path
 
     def authenticate(self):
-        """Login to provider
-        """
+        """Login to provider"""
         # If we have not yet successfully authenticated, attempt authentication
-        if (self.state['authenticated'] == False):
+        if self.state["authenticated"] is False:
             # Erase any previous data
             self.auth_data = {}
             try:
@@ -430,11 +435,11 @@ class XTream():
                     self.auth_data = r.json()
                     self.authorization = {
                         "username": self.auth_data["user_info"]["username"],
-                        "password": self.auth_data["user_info"]["password"]
+                        "password": self.auth_data["user_info"]["password"],
                     }
-                    self.state['authenticated'] = True
+                    self.state["authenticated"] = True
                 else:
-                    print("Provider `{}` could not be loaded. Reason: `{} {}`".format(self.name,r.status_code, r.reason))
+                    print("Provider `{}` could not be loaded. Reason: `{} {}`".format(self.name, r.status_code, r.reason))
             except requests.exceptions.ConnectionError:
                 # If connection refused
                 print("{} - Connection refused URL: {}".format(self.name, self.server))
@@ -448,7 +453,7 @@ class XTream():
         Returns:
             dict: Dictionary if found and no errors, None if file does not exists
         """
-        #Build the full path
+        # Build the full path
         full_filename = osp.join(self.cache_path, "{}-{}".format(
                 self._slugify(self.name),
                 filename
@@ -466,7 +471,7 @@ class XTream():
             if self.threshold_time_sec > diff_time:
                 # Load the JSON data
                 try:
-                    with open(full_filename,mode='r',encoding='utf-8') as myfile:
+                    with open(full_filename, mode="r", encoding="utf-8") as myfile:
                         my_data = json.load(myfile)
                         if len(my_data) == 0:
                             my_data = None
@@ -490,7 +495,7 @@ class XTream():
         Returns:
             bool: True if successfull, False if error
         """
-        if data_list != None:
+        if data_list is not None:
 
             #Build the full path
             full_filename = osp.join(self.cache_path, "{}-{}".format(
@@ -500,7 +505,7 @@ class XTream():
             # If the path makes sense, save the file
             json_data = json.dumps(data_list, ensure_ascii=False)
             try:
-                with open(full_filename, mode='wt', encoding='utf-8') as myfile:
+                with open(full_filename, mode="wt", encoding="utf-8") as myfile:
                     myfile.write(json_data)
             except Exception as e:
                 print(" - Could not save to file `{}`: e=`{}`".format(
@@ -525,8 +530,8 @@ class XTream():
 
         """
         # If pyxtream has already authenticated the connection and not loaded the data, start loading
-        if (self.state['authenticated'] == True):
-            if (self.state['loaded'] == False):
+        if self.state["authenticated"] is True:
+            if self.state["loaded"] is False:
 
                 for loading_stream_type in (self.live_type, self.vod_type, self.series_type):
                     ## Get GROUPS
@@ -537,19 +542,19 @@ class XTream():
                         loading_stream_type
                     ))
                     # If file empty or does not exists, download it from remote
-                    if all_cat == None:
+                    if all_cat is None:
                         # Load all Groups and save file locally
                         start = timer()
                         all_cat = self._load_categories_from_provider(loading_stream_type)
                         self._save_to_file(all_cat,"all_groups_{}.json".format(
                             loading_stream_type
                         ))
-                        dt = timer()-start
+                        dt = timer() - start
 
                     # If we got the GROUPS data, show the statistics and load GROUPS
-                    if all_cat != None:
+                    if all_cat is not None:
                         print("Loaded {} {} Groups in {:.3f} seconds".format(
-                            len(all_cat),loading_stream_type,dt
+                            len(all_cat), loading_stream_type, dt
                         ))
                         ## Add GROUPS to dictionaries
 
@@ -563,7 +568,7 @@ class XTream():
                             self.groups.append(new_group)
 
                         # Add the catch-all-errors group
-                        self.groups.append(Group({"category_id": "9999","category_name":"xEverythingElse","parent_id":0},loading_stream_type))
+                        self.groups.append(Group({"category_id": "9999", "category_name": "xEverythingElse", "parent_id": 0}, loading_stream_type))
 
                         # Sort Categories
                         self.groups.sort(key=lambda x: x.name)
@@ -579,19 +584,19 @@ class XTream():
                         loading_stream_type
                     ))
                     # If file empty or does not exists, download it from remote
-                    if all_streams == None:
+                    if all_streams is None:
                         # Load all Streams and save file locally
                         start = timer()
                         all_streams = self._load_streams_from_provider(loading_stream_type)
                         self._save_to_file(all_streams,"all_stream_{}.json".format(
                             loading_stream_type
                         ))
-                        dt = timer()-start
+                        dt = timer() - start
 
                     # If we got the STREAMS data, show the statistics and load Streams
-                    if all_streams != None:
+                    if all_streams is not None:
                         print("Loaded {} {} Streams in {:.3f} seconds".format(
-                            len(all_streams),loading_stream_type,dt
+                            len(all_streams), loading_stream_type, dt
                         ))
                         ## Add Streams to dictionaries
 
@@ -602,7 +607,7 @@ class XTream():
                             skip_stream = False
 
                             # Skip if the name of the stream is empty
-                            if stream_channel['name'] == "":
+                            if stream_channel["name"] == "":
                                 skip_stream = True
                                 skipped_no_name_content = skipped_no_name_content + 1
                                 self._save_to_file_skipped_streams(stream_channel)
@@ -610,31 +615,31 @@ class XTream():
                             # Skip if the user chose to hide adult streams
                             if self.hide_adult_content and loading_stream_type == self.live_type:
                                 try:
-                                    if stream_channel['is_adult'] == "1":
+                                    if stream_channel["is_adult"] == "1":
                                         skip_stream = True
                                         skipped_adult_content = skipped_adult_content + 1
                                         self._save_to_file_skipped_streams(stream_channel)
-                                except:
+                                except Exception:
                                     print(" - Stream does not have `is_adult` key:\n\t`{}`".format(json.dumps(stream_channel)))
                                     pass
 
                             if not skip_stream:
                                 # Some channels have no group,
                                 # so let's add them to the catch all group
-                                if stream_channel['category_id'] == None:
-                                    stream_channel['category_id'] = '9999'
-                                elif stream_channel['category_id'] != '1':
+                                if stream_channel["category_id"] is None:
+                                    stream_channel["category_id"] = "9999"
+                                elif stream_channel["category_id"] != "1":
                                     pass
 
                                 # Find the first occurence of the group that the
                                 # Channel or Stream is pointing to
                                 the_group = next(
-                                    (x for x in self.groups if x.group_id == int(stream_channel['category_id'])),
+                                    (x for x in self.groups if x.group_id == int(stream_channel["category_id"])),
                                     None
                                 )
 
                                 # Set group title
-                                if the_group != None:
+                                if the_group is not None:
                                     group_title = the_group.name
                                 else:
                                     group_title = self.catch_all_group.name
@@ -651,12 +656,10 @@ class XTream():
 
                                 else:
                                     new_channel = Channel(
-                                        self,
-                                        group_title,
-                                        stream_channel
+                                        self, group_title, stream_channel
                                     )
 
-                                if (new_channel.group_id == '9999'):
+                                if new_channel.group_id == "9999":
                                     print(" - xEverythingElse Channel -> {} - {}".format(new_channel.name,new_channel.stream_type))
 
                                 # Save the new channel to the local list of channels
@@ -668,13 +671,13 @@ class XTream():
                                     self.series.append(new_series)
 
                                 # Add stream to the specific Group
-                                if the_group != None:
+                                if the_group is not None:
                                     if loading_stream_type != self.series_type:
                                         the_group.channels.append(new_channel)
                                     else:
                                         the_group.series.append(new_series)
                                 else:
-                                    print(" - Group not found `{}`".format(stream_channel['name']))
+                                    print(" - Group not found `{}`".format(stream_channel["name"]))
 
                         # Print information of which streams have been skipped
                         if self.hide_adult_content:
@@ -684,7 +687,7 @@ class XTream():
                     else:
                         print(" - Could not load {} Streams".format(loading_stream_type))
 
-                    self.state['loaded'] = True
+                    self.state["loaded"] = True
 
             else:
                 print("Warning, data has already been loaded.")
@@ -693,13 +696,13 @@ class XTream():
 
     def _save_to_file_skipped_streams(self, stream_channel: Channel):
 
-        #Build the full path
+        # Build the full path
         full_filename = osp.join(self.cache_path, "skipped_streams.json")
 
         # If the path makes sense, save the file
         json_data = json.dumps(stream_channel, ensure_ascii=False)
         try:
-            with open(full_filename, mode='a', encoding='utf-8') as myfile:
+            with open(full_filename, mode="a", encoding="utf-8") as myfile:
                 myfile.writelines(json_data)
         except Exception as e:
             print(" - Could not save to skipped stream file `{}`: e=`{}`".format(
@@ -715,25 +718,22 @@ class XTream():
         """
         start = timer()
         series_seasons = self._load_series_info_by_id_from_provider(get_series.series_id)
-        dt = timer()-start
-        #print("Loaded in {:.3f} sec".format(dt))
+        dt = timer() - start
+        # print("Loaded in {:.3f} sec".format(dt))
         for series_info in series_seasons["seasons"]:
             season_name = series_info["name"]
-            season_key = series_info['season_number']
+            season_key = series_info["season_number"]
             season = Season(season_name)
             get_series.seasons[season_name] = season
             if "episodes" in series_seasons.keys():
                 for series_season in series_seasons["episodes"].keys():
                     for episode_info in series_seasons["episodes"][str(series_season)]:
                         new_episode_channel = Episode(
-                            self,
-                            series_info,
-                            "Testing",
-                            episode_info
+                            self, series_info, "Testing", episode_info
                         )
-                        season.episodes[episode_info['title']] = new_episode_channel
+                        season.episodes[episode_info["title"]] = new_episode_channel
 
-    def _get_request(self, URL: str, timeout: Tuple = (2,15)):
+    def _get_request(self, URL: str, timeout: Tuple = (2, 15)):
         """Generic GET Request with Error handling
 
         Args:
@@ -744,7 +744,7 @@ class XTream():
             [type]: JSON dictionary of the loaded data, or None
         """
         try:
-            r = requests.get(URL,timeout=timeout)
+            r = requests.get(URL, timeout=timeout)
             if r.status_code == 200:
                 return r.json()
 
@@ -757,7 +757,7 @@ class XTream():
         except requests.exceptions.TooManyRedirects:
             print(" - TooManyRedirects")
 
-        except requests.exceptions.ReadTimeout as e:
+        except requests.exceptions.ReadTimeout:
             print(" - Timeout while loading data")
 
         return None
@@ -869,69 +869,67 @@ class XTream():
     def allEpg(self):
         return self._get_request(self.get_all_epg_URL())
 
-
     ## URL-builder methods
-
     def get_authenticate_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s' % (self.server, self.username, self.password)
+        URL = "%s/player_api.php?username=%s&password=%s" % (self.server, self.username, self.password)
         return URL
 
     def get_live_categories_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_live_categories')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_live_categories")
         return URL
 
     def get_live_streams_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_live_streams')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_live_streams")
         return URL
 
     def get_live_streams_URL_by_category(self, category_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s' % (self.server, self.username, self.password, 'get_live_streams', category_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s" % (self.server, self.username, self.password, "get_live_streams", category_id)
         return URL
 
     def get_vod_cat_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_vod_categories')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_vod_categories")
         return URL
 
     def get_vod_streams_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_vod_streams')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_vod_streams")
         return URL
 
     def get_vod_streams_URL_by_category(self, category_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s' % (self.server, self.username, self.password, 'get_vod_streams', category_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s" % (self.server, self.username, self.password, "get_vod_streams", category_id)
         return URL
 
     def get_series_cat_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_series_categories')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_series_categories")
         return URL
 
     def get_series_URL(self):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s' % (self.server, self.username, self.password, 'get_series')
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s" % (self.server, self.username, self.password, "get_series")
         return URL
 
     def get_series_URL_by_category(self, category_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s' % (self.server, self.username, self.password, 'get_series', category_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&category_id=%s" % (self.server, self.username, self.password, "get_series", category_id)
         return URL
 
     def get_series_info_URL_by_ID(self, series_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&series_id=%s' % (self.server, self.username, self.password, 'get_series_info', series_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&series_id=%s" % (self.server, self.username, self.password, "get_series_info", series_id)
         return URL
 
     def get_VOD_info_URL_by_ID(self, vod_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&vod_id=%s' % (self.server, self.username, self.password, 'get_vod_info', vod_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&vod_id=%s" % (self.server, self.username, self.password, "get_vod_info", vod_id)
         return URL
 
     def get_live_epg_URL_by_stream(self, stream_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s' % (self.server, self.username, self.password, 'get_short_epg', stream_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s" % (self.server, self.username, self.password, "get_short_epg", stream_id)
         return URL
 
     def get_live_epg_URL_by_stream_and_limit(self, stream_id, limit):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s&limit=%s' % (self.server, self.username, self.password, 'get_short_epg', stream_id, limit)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s&limit=%s" % (self.server, self.username, self.password, "get_short_epg", stream_id, limit)
         return URL
 
     def get_all_live_epg_URL_by_stream(self, stream_id):
-        URL = '%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s' % (self.server, self.username, self.password, 'get_simple_data_table', stream_id)
+        URL = "%s/player_api.php?username=%s&password=%s&action=%s&stream_id=%s" % (self.server, self.username, self.password, "get_simple_data_table", stream_id)
         return URL
 
     def get_all_epg_URL(self):
-        URL = '%s/xmltv.php?username=%s&password=%s' % (self.server, self.username, self.password)
+        URL = "%s/xmltv.php?username=%s&password=%s" % (self.server, self.username, self.password)
         return URL
